# -*- coding: utf-8 -*-
# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import proto  # type: ignore

from google.protobuf import timestamp_pb2  # type: ignore


__protobuf__ = proto.module(
    package="grafeas.v1", manifest={"DeploymentNote", "DeploymentOccurrence",},
)


class DeploymentNote(proto.Message):
    r"""An artifact that can be deployed in some runtime.

    Attributes:
        resource_uri (Sequence[str]):
            Required. Resource URI for the artifact being
            deployed.
    """

    resource_uri = proto.RepeatedField(proto.STRING, number=1,)


class DeploymentOccurrence(proto.Message):
    r"""The period during which some deployable was active in a
    runtime.

    Attributes:
        user_email (str):
            Identity of the user that triggered this
            deployment.
        deploy_time (google.protobuf.timestamp_pb2.Timestamp):
            Required. Beginning of the lifetime of this
            deployment.
        undeploy_time (google.protobuf.timestamp_pb2.Timestamp):
            End of the lifetime of this deployment.
        config (str):
            Configuration used to create this deployment.
        address (str):
            Address of the runtime element hosting this
            deployment.
        resource_uri (Sequence[str]):
            Output only. Resource URI for the artifact
            being deployed taken from the deployable field
            with the same name.
        platform (grafeas.grafeas_v1.types.DeploymentOccurrence.Platform):
            Platform hosting this deployment.
    """

    class Platform(proto.Enum):
        r"""Types of platforms."""
        PLATFORM_UNSPECIFIED = 0
        GKE = 1
        FLEX = 2
        CUSTOM = 3

    user_email = proto.Field(proto.STRING, number=1,)
    deploy_time = proto.Field(proto.MESSAGE, number=2, message=timestamp_pb2.Timestamp,)
    undeploy_time = proto.Field(
        proto.MESSAGE, number=3, message=timestamp_pb2.Timestamp,
    )
    config = proto.Field(proto.STRING, number=4,)
    address = proto.Field(proto.STRING, number=5,)
    resource_uri = proto.RepeatedField(proto.STRING, number=6,)
    platform = proto.Field(proto.ENUM, number=7, enum=Platform,)


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import proto  # type: ignore

from grafeas.grafeas_v1.types import vulnerability


__protobuf__ = proto.module(
    package="grafeas.v1",
    manifest={
        "ComplianceNote",
        "ComplianceVersion",
        "ComplianceOccurrence",
        "NonCompliantFile",
    },
)


class ComplianceNote(proto.Message):
    r"""

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        title (str):
            The title that identifies this compliance
            check.
        description (str):
            A description about this compliance check.
        version (Sequence[grafeas.grafeas_v1.types.ComplianceVersion]):
            The OS and config versions the benchmark
            applies to.
        rationale (str):
            A rationale for the existence of this
            compliance check.
        remediation (str):
            A description of remediation steps if the
            compliance check fails.
        cis_benchmark (grafeas.grafeas_v1.types.ComplianceNote.CisBenchmark):

            This field is a member of `oneof`_ ``compliance_type``.
        scan_instructions (bytes):
            Serialized scan instructions with a
            predefined format.
    """

    class CisBenchmark(proto.Message):
        r"""A compliance check that is a CIS benchmark.

        Attributes:
            profile_level (int):

            severity (grafeas.grafeas_v1.types.Severity):

        """

        profile_level = proto.Field(proto.INT32, number=1,)
        severity = proto.Field(proto.ENUM, number=2, enum=vulnerability.Severity,)

    title = proto.Field(proto.STRING, number=1,)
    description = proto.Field(proto.STRING, number=2,)
    version = proto.RepeatedField(proto.MESSAGE, number=3, message="ComplianceVersion",)
    rationale = proto.Field(proto.STRING, number=4,)
    remediation = proto.Field(proto.STRING, number=5,)
    cis_benchmark = proto.Field(
        proto.MESSAGE, number=6, oneof="compliance_type", message=CisBenchmark,
    )
    scan_instructions = proto.Field(proto.BYTES, number=7,)


class ComplianceVersion(proto.Message):
    r"""Describes the CIS benchmark version that is applicable to a
    given OS and os version.

    Attributes:
        cpe_uri (str):
            The CPE URI
            (https://cpe.mitre.org/specification/) this
            benchmark is applicable to.
        version (str):
            The version of the benchmark. This is set to
            the version of the OS-specific CIS document the
            benchmark is defined in.
    """

    cpe_uri = proto.Field(proto.STRING, number=1,)
    version = proto.Field(proto.STRING, number=2,)


class ComplianceOccurrence(proto.Message):
    r"""An indication that the compliance checks in the associated
    ComplianceNote were not satisfied for particular resources or a
    specified reason.

    Attributes:
        non_compliant_files (Sequence[grafeas.grafeas_v1.types.NonCompliantFile]):

        non_compliance_reason (str):

    """

    non_compliant_files = proto.RepeatedField(
        proto.MESSAGE, number=2, message="NonCompliantFile",
    )
    non_compliance_reason = proto.Field(proto.STRING, number=3,)


class NonCompliantFile(proto.Message):
    r"""Details about files that caused a compliance check to fail.

    Attributes:
        path (str):
            Empty if ``display_command`` is set.
        display_command (str):
            Command to display the non-compliant files.
        reason (str):
            Explains why a file is non compliant for a
            CIS check.
    """

    path = proto.Field(proto.STRING, number=1,)
    display_command = proto.Field(proto.STRING, number=2,)
    reason = proto.Field(proto.STRING, number=3,)


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import proto  # type: ignore


__protobuf__ = proto.module(package="grafeas.v1", manifest={"CVSSv3",},)


class CVSSv3(proto.Message):
    r"""Common Vulnerability Scoring System version 3.
    For details, see https://www.first.org/cvss/specification-
    document

    Attributes:
        base_score (float):
            The base score is a function of the base
            metric scores.
        exploitability_score (float):

        impact_score (float):

        attack_vector (grafeas.grafeas_v1.types.CVSSv3.AttackVector):
            Base Metrics
            Represents the intrinsic characteristics of a
            vulnerability that are constant over time and
            across user environments.
        attack_complexity (grafeas.grafeas_v1.types.CVSSv3.AttackComplexity):

        privileges_required (grafeas.grafeas_v1.types.CVSSv3.PrivilegesRequired):

        user_interaction (grafeas.grafeas_v1.types.CVSSv3.UserInteraction):

        scope (grafeas.grafeas_v1.types.CVSSv3.Scope):

        confidentiality_impact (grafeas.grafeas_v1.types.CVSSv3.Impact):

        integrity_impact (grafeas.grafeas_v1.types.CVSSv3.Impact):

        availability_impact (grafeas.grafeas_v1.types.CVSSv3.Impact):

    """

    class AttackVector(proto.Enum):
        r""""""
        ATTACK_VECTOR_UNSPECIFIED = 0
        ATTACK_VECTOR_NETWORK = 1
        ATTACK_VECTOR_ADJACENT = 2
        ATTACK_VECTOR_LOCAL = 3
        ATTACK_VECTOR_PHYSICAL = 4

    class AttackComplexity(proto.Enum):
        r""""""
        ATTACK_COMPLEXITY_UNSPECIFIED = 0
        ATTACK_COMPLEXITY_LOW = 1
        ATTACK_COMPLEXITY_HIGH = 2

    class PrivilegesRequired(proto.Enum):
        r""""""
        PRIVILEGES_REQUIRED_UNSPECIFIED = 0
        PRIVILEGES_REQUIRED_NONE = 1
        PRIVILEGES_REQUIRED_LOW = 2
        PRIVILEGES_REQUIRED_HIGH = 3

    class UserInteraction(proto.Enum):
        r""""""
        USER_INTERACTION_UNSPECIFIED = 0
        USER_INTERACTION_NONE = 1
        USER_INTERACTION_REQUIRED = 2

    class Scope(proto.Enum):
        r""""""
        SCOPE_UNSPECIFIED = 0
        SCOPE_UNCHANGED = 1
        SCOPE_CHANGED = 2

    class Impact(proto.Enum):
        r""""""
        IMPACT_UNSPECIFIED = 0
        IMPACT_HIGH = 1
        IMPACT_LOW = 2
        IMPACT_NONE = 3

    base_score = proto.Field(proto.FLOAT, number=1,)
    exploitability_score = proto.Field(proto.FLOAT, number=2,)
    impact_score = proto.Field(proto.FLOAT, number=3,)
    attack_vector = proto.Field(proto.ENUM, number=5, enum=AttackVector,)
    attack_complexity = proto.Field(proto.ENUM, number=6, enum=AttackComplexity,)
    privileges_required = proto.Field(proto.ENUM, number=7, enum=PrivilegesRequired,)
    user_interaction = proto.Field(proto.ENUM, number=8, enum=UserInteraction,)
    scope = proto.Field(proto.ENUM, number=9, enum=Scope,)
    confidentiality_impact = proto.Field(proto.ENUM, number=10, enum=Impact,)
    integrity_impact = proto.Field(proto.ENUM, number=11, enum=Impact,)
    availability_impact = proto.Field(proto.ENUM, number=12, enum=Impact,)


__all__ = tuple(sorted(__protobuf__.manifest))
